@@ -11,7 +11,7 @@ SV * Perl_vstringify(pTHX_ SV *vs);
 int Perl_vcmp(pTHX_ SV *lsv, SV *rsv);
 
 #define SCAN_VERSION(a,b,c)	Perl_scan_version(aTHX_ a,b,c)
-#define new_version(a)		Perl_new_version(aTHX_ a)
+#define NEW_VERSION(a)		Perl_new_version(aTHX_ a)
 #define UPG_VERSION(a,b)	Perl_upg_version(aTHX_ a, b)
 #define vverify(a)		Perl_vverify(aTHX_ a)
 #define vnumify(a)		Perl_vnumify(aTHX_ a)
@@ -21,9 +21,12 @@ int Perl_vcmp(pTHX_ SV *lsv, SV *rsv);
 #define vcmp(a,b)		Perl_vcmp(aTHX_ a,b)
 #else
 const char * Perl_scan_version2(pTHX_ const char *s, SV *rv, bool qv);
+SV * Perl_new_version2(pTHX_ SV *ver);
 SV * Perl_upg_version2(pTHX_ SV *sv, bool qv);
 #define SCAN_VERSION(a,b,c)	Perl_scan_version2(aTHX_ a,b,c)
+#define NEW_VERSION(a)		Perl_new_version2(aTHX_ a)
 #define UPG_VERSION(a,b)	Perl_upg_version2(aTHX_ a, b)
+#define vcmp(a,b)		Perl_vcmp(aTHX_ a,b)
 #endif
 
 SV * Perl_vstringify2(pTHX_ SV *vs);
